/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React from 'react'
import styled from 'styled-components'
import UserDescription from './UserDescription.js'
import NoContentImage from '../../../img/img-16.png'
import Template from '../PanelComponents/TemplateRecurso'
import PanelTemplateColecao from '../PanelComponents/TemplateColecao.js'

const NoContentContainer = styled.div`
    height : 250px;
    display : flex;
    justify-content : center;
    align-content : center;
    text-align : center;

    h3 {
        font-size : 24px;
        font-weight : lighter;
        margin-top : 20px;
        margin-bottom : 10px;
    }

    p {
        font-size : 15px;
        font-weight : lighter;
        margin : 0 0 10px;
    }
`
/*Displays given image and text saying user hasn't posted anything yet*/
export function NoContent(props) {
    return (
        <NoContentContainer>
            <div style={{ paddingTop: "1em" }}>
                <img alt="" src={props.image} style={{ width: "130px", verticalAlign: "middle", border: "0" }} />
                <h3>
                    {props.text1}
                </h3>
                <p>
                    {props.text2}
                </p>
            </div>
        </NoContentContainer>

    )
}

export default function TabInicio({ id, user, learningObjs, collections }) {
    return (
        <React.Fragment>
            {/*display user description*/}
            {
                user.description &&
                <UserDescription text={user.description} />
            }
            <Template
                length={learningObjs.length}
                titleText={learningObjs.length === 1 ? `Recurso de ${user.name}` : `Recursos de ${user.name}`}
                noContentText={`${user.name} não publicou nenhum recursos ainda`}
                slice={learningObjs}
                showMore={() => { }} // there is no function here, because we don't want to display more resources in this tab
                loadingMore={false}
                end={learningObjs.length}
                error={false}
            />
            <PanelTemplateColecao
                title={`Coleçoes de ${user.name}`}
                length={collections.length}
                noContentText={`${user.name} não publicou nenhuma coleção ainda`}
                sliceArr={collections}
                showMore={() => { }} // there is no function here, because we don't want to display more collections in this tab
                loadingMore={false}
                end={collections.length}
                followed={false}
                error={false}
            />


        </React.Fragment>

    )
}
